@@ -6,8 +6,8 @@
 # https://github.com/tsfpga/tsfpga
 # --------------------------------------------------------------------------------------------------
 
-create_ip -vlnv xilinx.com:ip:fifo_generator:13.2 -module_name fifo_generator_0
+create_ip -vlnv "xilinx.com:ip:fifo_generator:13.2" -module_name "fifo_generator_0"
 set_property -dict [list \
-  CONFIG.Input_Data_Width "24" \
-  CONFIG.Output_Data_Width "24" \
-] [get_ips fifo_generator_0]
+  "CONFIG.Input_Data_Width" "24" \
+  "CONFIG.Output_Data_Width" "24" \
+] [get_ips "fifo_generator_0"]
