@@ -6,11 +6,11 @@
 # https://github.com/tsfpga/tsfpga
 # --------------------------------------------------------------------------------------------------
 
-create_ip -vlnv xilinx.com:ip:mult_gen:12.0 -module_name mult_u12_u5
+create_ip -vlnv "xilinx.com:ip:mult_gen:12.0" -module_name "mult_u12_u5"
 set_property -dict [list \
-  CONFIG.PortAType "Unsigned" \
-  CONFIG.PortAWidth "12" \
-  CONFIG.PortBType "Unsigned" \
-  CONFIG.PortBWidth "5" \
-  CONFIG.OutputWidthHigh "16" \
-] [get_ips mult_u12_u5]
+  "CONFIG.PortAType" "Unsigned" \
+  "CONFIG.PortAWidth" "12" \
+  "CONFIG.PortBType" "Unsigned" \
+  "CONFIG.PortBWidth" "5" \
+  "CONFIG.OutputWidthHigh" "16" \
+] [get_ips "mult_u12_u5"]
