@@ -16,7 +16,7 @@ if TYPE_CHECKING:
     # First party libraries
     from tsfpga.module_list import ModuleList
 
-# Do PYTHONPATH insert() instead of append() to prefer any local repo checkout over any pip install
+# Do PYTHONPATH insert() instead of append() to prefer any local repo checkout over any pip install.
 REPO_ROOT = Path(__file__).parent.parent.parent.resolve()
 sys.path.insert(0, str(REPO_ROOT))
 
@@ -50,16 +50,13 @@ def main() -> None:
     args = cli.parse_args()
 
     modules = get_tsfpga_example_modules()
-
-    # Avoid the module that depends on Xilinx unisim library
-    module_names_avoid = set(["hard_fifo"]) if args.vivado_skip else None
-    modules_no_sim = get_hdl_modules(names_avoid=module_names_avoid)
+    modules_no_sim = get_hdl_modules()
 
     if args.vcs_minimal:
         if args.test_patterns != "*":
             sys.exit(
                 "Can not specify a test pattern when using the --vcs-minimal flag."
-                f" Got {args.test_patterns}",
+                f' Got "{args.test_patterns}"',
             )
 
         test_filters = find_git_test_filters(
@@ -73,7 +70,7 @@ def main() -> None:
             print("Nothing to run. Appears to be no VHDL-related git diff.")
             return
 
-        # Override the test pattern argument to VUnit
+        # Override the test pattern argument to VUnit.
         args.test_patterns = test_filters
         print(f"Running VUnit with test pattern {args.test_patterns}")
 
@@ -81,11 +78,21 @@ def main() -> None:
         args.minimal = True
 
     simulation_project = SimulationProject(args=args)
-    simulation_project.add_modules(args=args, modules=modules, modules_no_sim=modules_no_sim)
+    simulation_project.add_modules(
+        args=args,
+        modules=modules,
+        modules_no_sim=modules_no_sim,
+        include_verilog_files=False,
+        include_systemverilog_files=False,
+    )
     simlib = simulation_project.add_vivado_simlib()
     ip_core_vivado_project_directory = simulation_project.add_vivado_ip_cores(
         modules=modules + modules_no_sim
     )
+    # Synopsys is needed by unisim MMCME2_ADV primitive.
+    # Relaxed rules needed by unisim VITAL2000 package.
+    # Do not use in any new code.
+    simulation_project.vunit_proj.set_sim_option("ghdl.elab_flags", ["-frelaxed", "-fsynopsys"])
 
     create_vhdl_ls_configuration(
         output_path=tsfpga.REPO_ROOT,
@@ -132,13 +139,19 @@ def find_git_test_filters(
     # Note that sources are added identical to the "real" project above.
     simulation_project = SimulationProject(args=args)
     simulation_project.add_modules(
-        args=args, modules=modules, modules_no_sim=modules_no_sim, **setup_vunit_kwargs
+        args=args,
+        modules=modules,
+        modules_no_sim=modules_no_sim,
+        include_verilog_files=False,
+        include_systemverilog_files=False,
+        **setup_vunit_kwargs,
     )
 
     testbenches_to_run = GitSimulationSubset(
         repo_root=repo_root,
         reference_branch=reference_branch,
         vunit_proj=simulation_project.vunit_proj,
+        modules=modules,
     ).find_subset()
 
     test_filters = []
