@@ -109,25 +109,45 @@ class BaseModule:
 
         return files
 
-    def _get_hdl_file_list(
+    def _get_hdl_file_list(  # pylint: disable=too-many-arguments
         self,
         folders: list[Path],
         files_include: Optional[set[Path]] = None,
         files_avoid: Optional[set[Path]] = None,
+        include_vhdl_files: bool = True,
+        include_verilog_files: bool = True,
+        include_systemverilog_files: bool = True,
     ) -> list[HdlFile]:
         """
         Return a list of HDL file objects.
         """
+        file_endings: tuple[str, ...] = tuple()
+        if include_vhdl_files:
+            file_endings += HdlFile.file_endings_mapping[HdlFile.Type.VHDL]
+        if include_verilog_files:
+            file_endings += HdlFile.file_endings_mapping[HdlFile.Type.VERILOG_SOURCE]
+            file_endings += HdlFile.file_endings_mapping[HdlFile.Type.VERILOG_HEADER]
+        if include_systemverilog_files:
+            file_endings += HdlFile.file_endings_mapping[HdlFile.Type.SYSTEMVERILOG_SOURCE]
+            file_endings += HdlFile.file_endings_mapping[HdlFile.Type.SYSTEMVERILOG_HEADER]
+
         return [
-            HdlFile(file_path)
+            HdlFile(path=file_path)
             for file_path in self._get_file_list(
                 folders=folders,
-                file_endings=HdlFile.file_endings,
+                file_endings=file_endings,
                 files_include=files_include,
                 files_avoid=files_avoid,
             )
         ]
 
+    @property
+    def register_data_file(self) -> Path:
+        """
+        The path to this module's register data file (which may or may not exist).
+        """
+        return self.path / f"regs_{self.name}.toml"
+
     @property
     def registers(self) -> Optional[RegisterList]:
         """
@@ -139,7 +159,7 @@ class BaseModule:
             # Only create object from TOML once.
             return self._registers
 
-        toml_file = self.path / f"regs_{self.name}.toml"
+        toml_file = self.register_data_file
         if toml_file.exists():
             self._registers = from_toml(
                 name=self.name, toml_file=toml_file, default_registers=self._default_registers
@@ -269,6 +289,9 @@ class BaseModule:
         self,
         files_include: Optional[set[Path]] = None,
         files_avoid: Optional[set[Path]] = None,
+        include_vhdl_files: bool = True,
+        include_verilog_files: bool = True,
+        include_systemverilog_files: bool = True,
         **kwargs: Any,
     ) -> list[HdlFile]:
         """
@@ -284,6 +307,12 @@ class BaseModule:
         Arguments:
             files_include: Optionally filter to only include these files.
             files_avoid: Optionally filter to discard these files.
+            include_vhdl_files: Optionally disable inclusion of files with VHDL
+                file endings.
+            include_verilog_files: Optionally disable inclusion of files with Verilog
+                file endings.
+            include_systemverilog_files: Optionally disable inclusion of files with SystemVerilog
+                file endings.
             kwargs: Further parameters that can be sent by build flow to control what
                 files are included.
 
@@ -293,14 +322,22 @@ class BaseModule:
         self.create_register_synthesis_files()
 
         return self._get_hdl_file_list(
-            folders=self.synthesis_folders, files_include=files_include, files_avoid=files_avoid
+            folders=self.synthesis_folders,
+            files_include=files_include,
+            files_avoid=files_avoid,
+            include_vhdl_files=include_vhdl_files,
+            include_verilog_files=include_verilog_files,
+            include_systemverilog_files=include_systemverilog_files,
         )
 
-    def get_simulation_files(
+    def get_simulation_files(  # pylint: disable=too-many-arguments
         self,
         include_tests: bool = True,
         files_include: Optional[set[Path]] = None,
         files_avoid: Optional[set[Path]] = None,
+        include_vhdl_files: bool = True,
+        include_verilog_files: bool = True,
+        include_systemverilog_files: bool = True,
         **kwargs: Any,
     ) -> list[HdlFile]:
         """
@@ -312,6 +349,12 @@ class BaseModule:
                 (the ``sim`` files are always included).
             files_include: Optionally filter to only include these files.
             files_avoid: Optionally filter to discard these files.
+            include_vhdl_files: Optionally disable inclusion of files with VHDL
+                file endings.
+            include_verilog_files: Optionally disable inclusion of files with Verilog
+                file endings.
+            include_systemverilog_files: Optionally disable inclusion of files with SystemVerilog
+                file endings.
             kwargs: Further parameters that can be sent by simulation flow to control what
                 files are included.
 
@@ -327,11 +370,21 @@ class BaseModule:
         self.create_register_simulation_files()
 
         test_files = self._get_hdl_file_list(
-            folders=sim_and_test_folders, files_include=files_include, files_avoid=files_avoid
+            folders=sim_and_test_folders,
+            files_include=files_include,
+            files_avoid=files_avoid,
+            include_vhdl_files=include_vhdl_files,
+            include_verilog_files=include_verilog_files,
+            include_systemverilog_files=include_systemverilog_files,
         )
 
         synthesis_files = self.get_synthesis_files(
-            files_include=files_include, files_avoid=files_avoid, **kwargs
+            files_include=files_include,
+            files_avoid=files_avoid,
+            include_vhdl_files=include_vhdl_files,
+            include_verilog_files=include_verilog_files,
+            include_systemverilog_files=include_systemverilog_files,
+            **kwargs,
         )
 
         return synthesis_files + test_files
@@ -340,6 +393,9 @@ class BaseModule:
         self,
         files_include: Optional[set[Path]] = None,
         files_avoid: Optional[set[Path]] = None,
+        include_vhdl_files: bool = True,
+        include_verilog_files: bool = True,
+        include_systemverilog_files: bool = True,
         **kwargs: Any,
     ) -> list[HdlFile]:
         """
@@ -349,6 +405,16 @@ class BaseModule:
         register package.
         Overwrite in a subclass if you want to change this behavior.
 
+        Arguments:
+            files_include: Optionally filter to only include these files.
+            files_avoid: Optionally filter to discard these files.
+            include_vhdl_files: Optionally disable inclusion of files with VHDL
+                file endings.
+            include_verilog_files: Optionally disable inclusion of files with Verilog
+                file endings.
+            include_systemverilog_files: Optionally disable inclusion of files with SystemVerilog
+                file endings.
+
         Return:
             Files that should be included in documentation.
         """
@@ -366,6 +432,9 @@ class BaseModule:
             folders=self.synthesis_folders + self.sim_folders,
             files_include=files_include,
             files_avoid=files_to_avoid,
+            include_vhdl_files=include_vhdl_files,
+            include_verilog_files=include_verilog_files,
+            include_systemverilog_files=include_systemverilog_files,
         )
 
     # pylint: disable=unused-argument
@@ -594,17 +663,21 @@ class BaseModule:
 
 
 def get_modules(
-    modules_folders: list[Path],
+    modules_folder: Optional[Path] = None,
+    modules_folders: Optional[list[Path]] = None,
     names_include: Optional[set[str]] = None,
     names_avoid: Optional[set[str]] = None,
     library_name_has_lib_suffix: bool = False,
     default_registers: Optional[list[Register]] = None,
 ) -> ModuleList:
     """
-    Get a list of Module objects based on the source code folders.
+    Get a list of module objects (:class:`BaseModule` or subclasses thereof) based on the source
+    code folders.
 
     Arguments:
-        modules_folders: A list of paths where your modules are located.
+        modules_folder: The path to the folder containing modules.
+        modules_folders: Optionally, you can specify many folders with modules that will all
+            be searched.
         names_include: If specified, only modules with these names will be included.
         names_avoid: If specified, modules with these names will be discarded.
         library_name_has_lib_suffix: If set, the library name will be ``<module name>_lib``,
@@ -612,12 +685,17 @@ def get_modules(
         default_registers: Default registers.
 
     Return:
-        List of module objects (:class:`BaseModule` or subclasses thereof)
-        created from the specified folders.
+        The modules created from the specified folders.
     """
     modules = ModuleList()
 
-    for module_folder in _iterate_module_folders(modules_folders):
+    folders = []
+    if modules_folder is not None:
+        folders.append(modules_folder)
+    if modules_folders is not None:
+        folders += modules_folders
+
+    for module_folder in _iterate_module_folders(folders):
         module_name = module_folder.name
 
         if names_include is not None and module_name not in names_include:
@@ -638,6 +716,46 @@ def get_modules(
     return modules
 
 
+def get_module(
+    name: str,
+    modules_folder: Optional[Path] = None,
+    modules_folders: Optional[list[Path]] = None,
+    library_name_has_lib_suffix: bool = False,
+    default_registers: Optional[list[Register]] = None,
+) -> BaseModule:
+    """
+    Get a single module object, for a module found in one of the specified source code folders.
+    Is a wrapper around :func:`.get_modules`.
+
+    Arguments:
+        name: The name of the module.
+        modules_folder: The path to the folder containing modules.
+        modules_folders: Optionally, you can specify many folders with modules that will all
+            be searched.
+        library_name_has_lib_suffix: If set, the library name will be ``<module name>_lib``,
+            otherwise it is just ``<module name>``.
+        default_registers: Default registers.
+
+    Return:
+        The requested module.
+    """
+    modules = get_modules(
+        modules_folder=modules_folder,
+        modules_folders=modules_folders,
+        names_include={name},
+        library_name_has_lib_suffix=library_name_has_lib_suffix,
+        default_registers=default_registers,
+    )
+
+    if not modules:
+        raise RuntimeError(f'Could not find module "{name}".')
+
+    if len(modules) > 1:
+        raise RuntimeError(f'Found multiple modules named "{name}".')
+
+    return modules[0]
+
+
 def _iterate_module_folders(modules_folders: list[Path]) -> Iterable[Path]:
     for modules_folder in modules_folders:
         for module_folder in modules_folder.glob("*"):
