@@ -13,11 +13,10 @@ from typing import TYPE_CHECKING, Optional
 # Third party libraries
 from hdl_registers.generator.html.page import HtmlPageGenerator
 
-# First party libraries
-from tsfpga.system_utils import create_file, file_is_in_directory, read_file
-from tsfpga.vhdl_file_documentation import VhdlFileDocumentation
-
 # Local folder libraries
+from .about import WEBSITE_URL
+from .system_utils import create_file, file_is_in_directory, read_file
+from .vhdl_file_documentation import VhdlFileDocumentation
 from .vivado.project import VivadoNetlistProject
 
 if TYPE_CHECKING:
@@ -32,12 +31,28 @@ class ModuleDocumentation:
     The content is extracted from VHDL source file headers.
     """
 
-    def __init__(self, module: "BaseModule") -> None:
+    def __init__(
+        self,
+        module: "BaseModule",
+        repository_url: Optional[str] = None,
+        repository_name: Optional[str] = None,
+    ) -> None:
         """
         Arguments:
             module: The module which shall be documented.
+            repository_url: Optionally specify an URL where the source code can be viewed.
+                If this argument is specified, links will be added to the documentation.
+                URL should be to the module folder within the repository.
+            repository_name: Optionally specify the name of the repository URL.
+                For example "GitLab".
         """
         self._module = module
+        self._repository_url = repository_url
+        self._repository_name = repository_name
+
+        assert (repository_url is None) == (
+            repository_name is None
+        ), "Both or none of the repository arguments must be set"
 
     def get_overview_rst(self) -> Optional[str]:
         """
@@ -155,6 +170,14 @@ register documentation.
         heading = f"Module {self._module.name}"
         heading_underline = heading_character_1 * len(heading)
 
+        if self._repository_url:
+            url_rst = (
+                f"To browse the source code, please visit the "
+                f"`repository on {self._repository_name} <{self._repository_url}>`__."
+            )
+        else:
+            url_rst = ""
+
         overview_rst = self.get_overview_rst()
         overview_rst = "" if overview_rst is None else overview_rst
 
@@ -175,6 +198,7 @@ register documentation.
 {heading_underline}
 
 This document contains technical documentation for the ``{self._module.name}`` module.
+{url_rst}
 
 {overview_rst}
 
@@ -211,15 +235,15 @@ This document contains technical documentation for the ``{self._module.name}`` m
         """
         Get VHDL files that shall be included in the documentation, in order.
         """
-        hdl_files = self._module.get_documentation_files(files_avoid=exclude_files)
+        # Exclude all file types except VHDL.
+        hdl_files = self._module.get_documentation_files(
+            files_avoid=exclude_files, include_verilog=False, include_systemverilog=False
+        )
 
         def file_should_be_included(hdl_file: "HdlFile") -> bool:
             if file_is_in_directory(hdl_file.path, exclude_folders):
                 return False
 
-            if not hdl_file.is_vhdl:
-                return False
-
             return True
 
         vhdl_file_paths = [
@@ -249,16 +273,25 @@ This document contains technical documentation for the ``{self._module.name}`` m
         file_rst = vhdl_file_documentation.get_header_rst()
         file_rst = "" if file_rst is None else file_rst
 
+        if self._repository_url:
+            url_rst = (
+                f"`View source code on {self._repository_name} "
+                f"<{self._repository_url}/{vhdl_file_path.relative_to(self._module.path)}>`__."
+            )
+        else:
+            url_rst = ""
+
         symbolator_rst = self._get_symbolator_rst(vhdl_file_documentation)
         symbolator_rst = "" if symbolator_rst is None else symbolator_rst
 
+        entity_name = vhdl_file_path.stem
+
         resource_utilization_rst = self._get_resource_utilization_rst(
-            vhdl_file_path=vhdl_file_path,
+            entity_name=entity_name,
             heading_character=heading_character_2,
             netlist_builds=netlist_builds,
         )
 
-        entity_name = vhdl_file_path.stem
         heading = f"{vhdl_file_path.name}"
         heading_underline = heading_character * len(heading)
 
@@ -268,6 +301,8 @@ This document contains technical documentation for the ``{self._module.name}`` m
 {heading}
 {heading_underline}
 
+{url_rst}
+
 {symbolator_rst}
 
 {file_rst}
@@ -293,10 +328,7 @@ This document contains technical documentation for the ``{self._module.name}`` m
         return rst
 
     def _get_resource_utilization_rst(  # pylint: disable=too-many-locals,too-many-branches
-        self,
-        vhdl_file_path: Path,
-        heading_character: str,
-        netlist_builds: list["VivadoNetlistProject"],
+        self, entity_name: str, heading_character: str, netlist_builds: list["VivadoNetlistProject"]
     ) -> str:
         # First, loop over all netlist builds for this module and assemble information
         generics = []
@@ -318,17 +350,26 @@ This document contains technical documentation for the ``{self._module.name}`` m
         if generics:
             heading = "Resource utilization"
             heading_underline = heading_character * len(heading)
+
+            module_py_name = f"module_{self._module.name}.py"
+            if self._repository_url:
+                module_py_rst = f"`{module_py_name} <{self._repository_url}/{module_py_name}>`__"
+            else:
+                module_py_rst = f"``{module_py_name}``"
+
             rst = f"""
+.. _{self._module.name}.{entity_name}.resource_utilization:
+
 {heading}
 {heading_underline}
 
-This entity has `netlist builds <https://tsfpga.com/netlist_build.html>`__ set up with
-`automatic size checkers <https://tsfpga.com/netlist_build.html#build-result-checkers>`__
-in ``module_{self._module.name}.py``.
+This entity has `netlist builds <{WEBSITE_URL}/netlist_build.html>`__ set up with
+`automatic size checkers <{WEBSITE_URL}/netlist_build.html#build-result-checkers>`__
+in {module_py_rst}.
 The following table lists the resource utilization for the entity, depending on
 generic configuration.
 
-.. list-table:: Resource utilization for {vhdl_file_path.name} netlist builds.
+.. list-table:: Resource utilization for **{entity_name}** netlist builds.
   :header-rows: 1
 
 """
@@ -353,10 +394,10 @@ generic configuration.
                 rst += f"""\
   * - {generics_rst}"""
 
-                # If the "top" of the project is different than this file name, we assume that it
+                # If the "top" of the project is different than the entity, we assume that it
                 # is a wrapper. Add a note to the table about this. This occurs e.g. in the reg_file
                 # and fifo modules.
-                if netlist_builds[build_idx].top != vhdl_file_path.stem:
+                if netlist_builds[build_idx].top != entity_name:
                     if generic_strings:
                         # If there is already something in the generic column, this note shall be
                         # placed on a new line.
