@@ -3,11 +3,16 @@
 #
 # This file is part of the tsfpga project, a project platform for modern FPGA development.
 # https://tsfpga.com
-# https://gitlab.com/tsfpga/tsfpga
+# https://github.com/tsfpga/tsfpga
 # --------------------------------------------------------------------------------------------------
 
 # Standard libraries
 import copy
+from typing import TYPE_CHECKING, Iterator
+
+if TYPE_CHECKING:
+    # Local folder libraries
+    from .module import BaseModule
 
 
 class ModuleList:
@@ -15,16 +20,16 @@ class ModuleList:
     Wrapper for a list of modules, with convenience functions.
     """
 
-    def __init__(self):
-        self._modules = []
+    def __init__(self) -> None:
+        self._modules: list["BaseModule"] = []
 
-    def append(self, module):
+    def append(self, module: "BaseModule") -> None:
         """
         Append a module to the list.
         """
         self._modules.append(module)
 
-    def get(self, module_name):
+    def get(self, module_name: "str") -> "BaseModule":
         """
         Get the module with the specified name. If no module matched, an exception is raised.
         """
@@ -34,16 +39,16 @@ class ModuleList:
 
         raise ValueError(f'No module "{module_name}" available')
 
-    def __iter__(self):
+    def __iter__(self) -> Iterator["BaseModule"]:
         return iter(self._modules)
 
-    def __getitem__(self, index):
+    def __getitem__(self, index: int) -> "BaseModule":
         return self._modules[index]
 
-    def __len__(self):
+    def __len__(self) -> int:
         return len(self._modules)
 
-    def __add__(self, other):
+    def __add__(self, other: "ModuleList") -> "ModuleList":
         if not isinstance(other, self.__class__):
             raise TypeError(f"Can only concatenate with another {self.__class__.__name__}")
 
@@ -52,17 +57,17 @@ class ModuleList:
         result._modules = self._modules + other._modules
         return result
 
-    def __copy__(self):
+    def __copy__(self) -> "ModuleList":
         result = self.__class__()
         result._modules = self._modules.copy()
         return result
 
-    def copy(self):
+    def copy(self) -> "ModuleList":
         """
         Create a shallow copy of the module list. This public function is available as a
         convenience and to mimic the interface of a regular python list.
         """
         return copy.copy(self)
 
-    def __str__(self):
+    def __str__(self) -> str:
         return str(self._modules)
