@@ -14,7 +14,7 @@ from unittest.mock import ANY, MagicMock, patch
 import pytest
 
 # First party libraries
-from tsfpga.module import BaseModule, get_modules
+from tsfpga.module import BaseModule, get_module, get_modules
 from tsfpga.system_utils import create_directory, create_file
 
 
@@ -104,7 +104,7 @@ def test_file_list_filtering(tmp_path):
         create_file(path / "syn.v"),
         create_file(path / "rtl" / "syn.v"),
         create_file(path / "src" / "syn.vhd"),
-        create_file(path / "hdl" / "rtl" / "syn.vhd"),
+        create_file(path / "hdl" / "rtl" / "syn.vhdl"),
         create_file(path / "hdl" / "package" / "syn.vhd"),
     }
 
@@ -136,8 +136,64 @@ def test_file_list_filtering(tmp_path):
 def test_get_synthesis_files_calls_get_simulation_files_with_correct_arguments():
     module = BaseModule(path=Path(), library_name="")
     with patch("tsfpga.module.BaseModule.get_synthesis_files") as get_synthesis_files:
-        module.get_simulation_files(files_include=True, files_avoid=False, apa=123)
-        get_synthesis_files.assert_called_once_with(files_include=True, files_avoid=False, apa=123)
+        module.get_simulation_files(
+            files_include=True,
+            files_avoid=False,
+            apa=123,
+            include_vhdl_files=1,
+            include_verilog_files=2,
+            include_systemverilog_files=3,
+        )
+        get_synthesis_files.assert_called_once_with(
+            files_include=True,
+            files_avoid=False,
+            apa=123,
+            include_vhdl_files=1,
+            include_verilog_files=2,
+            include_systemverilog_files=3,
+        )
+
+
+def test_get_vhdl_files(tmp_path):
+    paths = {
+        create_file(tmp_path / "apa.vhdl"),
+        create_file(tmp_path / "apa.vhd"),
+    }
+    create_file(tmp_path / "apa.v")
+    create_file(tmp_path / "apa.vh")
+    create_file(tmp_path / "apa.sv")
+    create_file(tmp_path / "apa.svh")
+
+    got_hdl_files = BaseModule(path=tmp_path, library_name="").get_synthesis_files(
+        include_verilog_files=False, include_systemverilog_files=False
+    )
+    assert {hdl_file.path for hdl_file in got_hdl_files} == paths
+
+
+def test_get_verilog_files(tmp_path):
+    paths = {create_file(tmp_path / "apa.v"), create_file(tmp_path / "apa.vh")}
+    create_file(tmp_path / "apa.vhdl")
+    create_file(tmp_path / "apa.vhd")
+    create_file(tmp_path / "apa.sv")
+    create_file(tmp_path / "apa.svh")
+
+    got_hdl_files = BaseModule(path=tmp_path, library_name="").get_simulation_files(
+        include_vhdl_files=False, include_systemverilog_files=False
+    )
+    assert {hdl_file.path for hdl_file in got_hdl_files} == paths
+
+
+def test_get_systemverilog_files(tmp_path):
+    paths = {create_file(tmp_path / "apa.sv"), create_file(tmp_path / "apa.svh")}
+    create_file(tmp_path / "apa.vhdl")
+    create_file(tmp_path / "apa.vhd")
+    create_file(tmp_path / "apa.v")
+    create_file(tmp_path / "apa.vh")
+
+    got_hdl_files = BaseModule(path=tmp_path, library_name="").get_documentation_files(
+        include_vhdl_files=False, include_verilog_files=False
+    )
+    assert {hdl_file.path for hdl_file in got_hdl_files} == paths
 
 
 def test_get_documentation_files(tmp_path):
@@ -224,7 +280,7 @@ def test_getting_registers_calls_registers_hook(tmp_path):
 
 
 def test_creating_synthesis_files_does_not_create_simulation_files(tmp_path):
-    create_file(tmp_path / "a" / "regs_a.toml", "register.apa.mode = 'r_w'")
+    create_file(tmp_path / "a" / "regs_a.toml", "apa.mode = 'r_w'")
     module = BaseModule(path=tmp_path / "a", library_name="a")
 
     synthesis_file = module.register_synthesis_folder / "a_regs_pkg.vhd"
@@ -240,7 +296,7 @@ def test_creating_synthesis_files_does_not_create_simulation_files(tmp_path):
 
 
 def test_old_register_package_should_be_deleted(tmp_path):
-    create_file(tmp_path / "a" / "regs_a.toml", "register.apa.mode = 'r_w'")
+    create_file(tmp_path / "a" / "regs_a.toml", "apa.mode = 'r_w'")
     regs_pkg = create_file(tmp_path / "a" / "a_regs_pkg.vhd")
 
     module = BaseModule(path=tmp_path / "a", library_name="a")
@@ -267,36 +323,75 @@ def get_modules_test(tmp_path):
 # pylint: disable=redefined-outer-name
 
 
+def test_get_module(get_modules_test):
+    module = get_module(name="a", modules_folder=get_modules_test.modules_folder)
+    assert module.name == "a"
+    assert module.library_name == "a"
+    assert module.path == get_modules_test.modules_folder / "a"
+
+    module = get_module(
+        name="b",
+        modules_folders=[get_modules_test.modules_folder],
+        library_name_has_lib_suffix=True,
+    )
+    assert module.name == "b"
+    assert module.library_name == "b_lib"
+    assert module.path == get_modules_test.modules_folder / "b"
+
+
+def test_get_module_not_found_should_raise_exception(get_modules_test):
+    with pytest.raises(RuntimeError) as exception_info:
+        get_module(name="d", modules_folder=get_modules_test.modules_folder)
+    assert str(exception_info.value) == 'Could not find module "d".'
+
+
+def test_get_module_found_multiple_should_raise_exception(get_modules_test):
+    create_directory(get_modules_test.modules_folder / "a" / "x")
+    create_directory(get_modules_test.modules_folder / "b" / "x")
+
+    with pytest.raises(RuntimeError) as exception_info:
+        get_module(
+            name="x",
+            modules_folders=[
+                get_modules_test.modules_folder / "a",
+                get_modules_test.modules_folder / "b",
+            ],
+        )
+    assert str(exception_info.value) == 'Found multiple modules named "x".'
+
+
 def test_name_filtering_include(get_modules_test):
-    modules = get_modules(get_modules_test.modules_folders, names_include=["a", "b"])
+    modules = get_modules(
+        modules_folders=get_modules_test.modules_folders, names_include=["a", "b"]
+    )
     assert set(module.name for module in modules) == set(["a", "b"])
 
 
 def test_name_filtering_avoid(get_modules_test):
-    modules = get_modules(get_modules_test.modules_folders, names_avoid=["a", "b"])
+    modules = get_modules(get_modules_test.modules_folder, names_avoid=["a", "b"])
     assert set(module.name for module in modules) == set(["c"])
 
 
 def test_name_filtering_include_and_avoid(get_modules_test):
     modules = get_modules(
-        get_modules_test.modules_folders, names_include=["a", "c"], names_avoid=["b", "c"]
+        get_modules_test.modules_folder, names_include=["a", "c"], names_avoid=["b", "c"]
     )
     assert set(module.name for module in modules) == set(["a"])
 
 
 def test_library_name_does_not_have_lib_suffix(get_modules_test):
-    modules = get_modules(get_modules_test.modules_folders)
+    modules = get_modules(get_modules_test.modules_folder)
     assert set(module.library_name for module in modules) == set(["a", "b", "c"])
 
 
 def test_library_name_has_lib_suffix(get_modules_test):
-    modules = get_modules(get_modules_test.modules_folders, library_name_has_lib_suffix=True)
+    modules = get_modules(get_modules_test.modules_folder, library_name_has_lib_suffix=True)
     assert set(module.library_name for module in modules) == set(["a_lib", "b_lib", "c_lib"])
 
 
 def test_stray_file_can_exist_in_modules_folder_without_error(get_modules_test):
     create_file(get_modules_test.modules_folder / "text_file.txt")
-    modules = get_modules(get_modules_test.modules_folders)
+    modules = get_modules(get_modules_test.modules_folder)
     assert len(modules) == 3
 
 
@@ -311,7 +406,7 @@ class Module(BaseModule):
     create_file(get_modules_test.modules_folder / "a" / "module_a.py", module_file_content + '"a"')
     create_file(get_modules_test.modules_folder / "b" / "module_b.py", module_file_content + '"b"')
 
-    modules = get_modules(get_modules_test.modules_folders)
+    modules = get_modules(get_modules_test.modules_folder)
 
     assert len(modules) == 3
     for module in modules:
@@ -326,56 +421,69 @@ class Module(BaseModule):
 
 
 @patch("tsfpga.module.from_toml", autospec=True)
-@patch("tsfpga.module.VhdlRegisterPackageGenerator.create", autospec=True)
-@patch("tsfpga.module.VhdlRecordPackageGenerator.create", autospec=True)
-@patch("tsfpga.module.VhdlSimulationReadWritePackageGenerator.create", autospec=True)
-@patch("tsfpga.module.VhdlSimulationWaitUntilPackageGenerator.create", autospec=True)
-@patch("tsfpga.module.VhdlAxiLiteWrapperGenerator.create", autospec=True)
+@patch("tsfpga.module.VhdlRegisterPackageGenerator.create_if_needed", autospec=True)
+@patch("tsfpga.module.VhdlRecordPackageGenerator.create_if_needed", autospec=True)
+@patch("tsfpga.module.VhdlAxiLiteWrapperGenerator.create_if_needed", autospec=True)
 def test_register_toml_file_parsed_only_once_when_getting_synthesis_files(
-    _, __, ___, ____, _____, from_toml, tmp_path
+    create3, create2, create1, from_toml, tmp_path
 ):
     toml_file = create_file(tmp_path / "a" / "regs_a.toml")
 
-    module = get_modules([tmp_path]).get("a")
+    module = get_modules(tmp_path).get("a")
     module.get_synthesis_files()
     module.get_synthesis_files()
 
     from_toml.assert_called_once_with("a", toml_file, ANY)
+    assert create3.call_count == 2
+    assert create2.call_count == 2
+    assert create1.call_count == 2
 
 
 @patch("tsfpga.module.from_toml", autospec=True)
-@patch("tsfpga.module.VhdlRegisterPackageGenerator.create", autospec=True)
-@patch("tsfpga.module.VhdlRecordPackageGenerator.create", autospec=True)
-@patch("tsfpga.module.VhdlAxiLiteWrapperGenerator.create", autospec=True)
-@patch("tsfpga.module.VhdlSimulationReadWritePackageGenerator.create", autospec=True)
-@patch("tsfpga.module.VhdlSimulationCheckPackageGenerator.create", autospec=True)
-@patch("tsfpga.module.VhdlSimulationWaitUntilPackageGenerator.create", autospec=True)
+@patch("tsfpga.module.VhdlRegisterPackageGenerator.create_if_needed", autospec=True)
+@patch("tsfpga.module.VhdlRecordPackageGenerator.create_if_needed", autospec=True)
+@patch("tsfpga.module.VhdlAxiLiteWrapperGenerator.create_if_needed", autospec=True)
+@patch("tsfpga.module.VhdlSimulationReadWritePackageGenerator.create_if_needed", autospec=True)
+@patch("tsfpga.module.VhdlSimulationCheckPackageGenerator.create_if_needed", autospec=True)
+@patch("tsfpga.module.VhdlSimulationWaitUntilPackageGenerator.create_if_needed", autospec=True)
 def test_register_toml_file_parsed_only_once_when_getting_simulation_files(
-    _, __, ___, ____, _____, ______, from_toml, tmp_path
-):
+    create6, create5, create4, create3, create2, create1, from_toml, tmp_path
+):  # pylint: disable=too-many-arguments
     toml_file = create_file(tmp_path / "a" / "regs_a.toml")
 
-    module = get_modules([tmp_path]).get("a")
+    module = get_modules(tmp_path).get("a")
     module.get_simulation_files()
     module.get_simulation_files()
 
     from_toml.assert_called_once_with("a", toml_file, ANY)
+    assert create6.call_count == 2
+    assert create5.call_count == 2
+    assert create4.call_count == 2
+    assert create3.call_count == 2
+    assert create2.call_count == 2
+    assert create1.call_count == 2
 
 
 @patch("tsfpga.module.from_toml", autospec=True)
-@patch("tsfpga.module.VhdlRegisterPackageGenerator.create", autospec=True)
-@patch("tsfpga.module.VhdlRecordPackageGenerator.create", autospec=True)
-@patch("tsfpga.module.VhdlAxiLiteWrapperGenerator.create", autospec=True)
-@patch("tsfpga.module.VhdlSimulationReadWritePackageGenerator.create", autospec=True)
-@patch("tsfpga.module.VhdlSimulationCheckPackageGenerator.create", autospec=True)
-@patch("tsfpga.module.VhdlSimulationWaitUntilPackageGenerator.create", autospec=True)
+@patch("tsfpga.module.VhdlRegisterPackageGenerator.create_if_needed", autospec=True)
+@patch("tsfpga.module.VhdlRecordPackageGenerator.create_if_needed", autospec=True)
+@patch("tsfpga.module.VhdlAxiLiteWrapperGenerator.create_if_needed", autospec=True)
+@patch("tsfpga.module.VhdlSimulationReadWritePackageGenerator.create_if_needed", autospec=True)
+@patch("tsfpga.module.VhdlSimulationCheckPackageGenerator.create_if_needed", autospec=True)
+@patch("tsfpga.module.VhdlSimulationWaitUntilPackageGenerator.create_if_needed", autospec=True)
 def test_register_toml_file_parsed_only_once_when_getting_mixed_files(
-    _, __, ___, ____, _____, ______, from_toml, tmp_path
-):
+    create6, create5, create4, create3, create2, create1, from_toml, tmp_path
+):  # pylint: disable=too-many-arguments
     toml_file = create_file(tmp_path / "a" / "regs_a.toml")
 
-    module = get_modules([tmp_path]).get("a")
+    module = get_modules(tmp_path).get("a")
     module.get_synthesis_files()
     module.get_simulation_files()
 
     from_toml.assert_called_once_with("a", toml_file, ANY)
+    assert create6.call_count == 1
+    assert create5.call_count == 1
+    assert create4.call_count == 1
+    assert create3.call_count == 2
+    assert create2.call_count == 2
+    assert create1.call_count == 2
